@@ -1,12 +1,16 @@
-import sys
+import platform
 import struct
+import sys
 
-__version__ = "0.4.7"
+__version__ = "0.4.9"
 
 
 def get_platform():
     bits = struct.calcsize("P") * 8
     if sys.platform.startswith("linux"):
+        architecture = platform.machine()
+        if architecture == "aarch64":
+            return "linuxaarch64"
         return "linux{}".format(bits)
     elif sys.platform.startswith("freebsd"):
         return "freebsd{}".format(bits)
