@@ -1,13 +1,12 @@
-import sys
-import time
 import pathlib
 import subprocess
-from functools import lru_cache
+import sys
+import time
 from collections import defaultdict
+from functools import lru_cache
 
-from ._utils import get_ffmpeg_exe, _popen_kwargs, logger
-from ._parsing import LogCatcher, parse_ffmpeg_header, cvsecs
-
+from ._parsing import LogCatcher, cvsecs, parse_ffmpeg_header
+from ._utils import _popen_kwargs, get_ffmpeg_exe, logger
 
 ISWIN = sys.platform.startswith("win")
 
@@ -34,7 +33,7 @@ def ffmpeg_test_encoder(encoder):
     # Use the null streams to validate if we can encode anything
     # https://trac.ffmpeg.org/wiki/Null
     cmd = [
-        _get_exe(),
+        get_ffmpeg_exe(),
         "-hide_banner",
         "-f",
         "lavfi",
@@ -56,7 +55,7 @@ def ffmpeg_test_encoder(encoder):
 
 
 def get_compiled_h264_encoders():
-    cmd = [_get_exe(), "-hide_banner", "-encoders"]
+    cmd = [get_ffmpeg_exe(), "-hide_banner", "-encoders"]
     p = subprocess.run(
         cmd,
         stdin=subprocess.PIPE,
@@ -132,11 +131,6 @@ def get_first_available_h264_encoder():
         )
 
 
-@lru_cache()
-def _get_exe():
-    return get_ffmpeg_exe()
-
-
 def count_frames_and_secs(path):
     """
     Get the number of frames and number of seconds for the given video
@@ -153,12 +147,25 @@ def count_frames_and_secs(path):
     if not isinstance(path, str):
         raise TypeError("Video path must be a string or pathlib.Path.")
 
-    cmd = [_get_exe(), "-i", path, "-map", "0:v:0", "-c", "copy", "-f", "null", "-"]
+    cmd = [
+        get_ffmpeg_exe(),
+        "-i",
+        path,
+        "-map",
+        "0:v:0",
+        "-c",
+        "copy",
+        "-f",
+        "null",
+        "-",
+    ]
     try:
         out = subprocess.check_output(cmd, stderr=subprocess.STDOUT, **_popen_kwargs())
     except subprocess.CalledProcessError as err:
         out = err.output.decode(errors="ignore")
-        raise RuntimeError("FFMEG call failed with {}:\n{}".format(err.returncode, out))
+        raise RuntimeError(
+            "FFMPEG call failed with {}:\n{}".format(err.returncode, out)
+        )
 
     # Note that other than with the subprocess calls below, ffmpeg wont hang here.
     # Worst case Python will stop/crash and ffmpeg will continue running until done.
@@ -254,11 +261,11 @@ def read_frames(
 
     pre_output_params = ["-pix_fmt", pix_fmt, "-vcodec", "rawvideo", "-f", "image2pipe"]
 
-    cmd = [_get_exe()]
+    cmd = [get_ffmpeg_exe()]
     cmd += input_params + ["-i", path]
     cmd += pre_output_params + output_params + ["-"]
 
-    p = subprocess.Popen(
+    process = subprocess.Popen(
         cmd,
         stdin=subprocess.PIPE,
         stdout=subprocess.PIPE,
@@ -266,7 +273,7 @@ def read_frames(
         **_popen_kwargs(prevent_sigint=True)
     )
 
-    log_catcher = LogCatcher(p.stderr)
+    log_catcher = LogCatcher(process.stderr)
 
     # Init policy by which to terminate ffmpeg. May be set to "kill" later.
     stop_policy = "timeout"  # not wait; ffmpeg should be able to quit quickly
@@ -276,7 +283,6 @@ def read_frames(
     # Generators are automatically closed when they get deleted,
     # so the finally block is guaranteed to run.
     try:
-
         # ----- Load meta data
 
         # Wait for the log catcher to get the meta information
@@ -297,8 +303,8 @@ def read_frames(
 
         # ----- Read frames
 
-        w, h = meta["size"]
-        framesize_bits = w * h * bits_per_pixel
+        width, height = meta["size"]
+        framesize_bits = width * height * bits_per_pixel
         framesize_bytes = framesize_bits / 8
         assert (
             framesize_bytes.is_integer()
@@ -311,7 +317,7 @@ def read_frames(
             try:
                 bb = bytes()
                 while len(bb) < framesize_bytes:
-                    extra_bytes = p.stdout.read(framesize_bytes - len(bb))
+                    extra_bytes = process.stdout.read(framesize_bytes - len(bb))
                     if not extra_bytes:
                         if len(bb) == 0:
                             return
@@ -345,8 +351,7 @@ def read_frames(
         log_catcher.stop_me()
 
         # Make sure that ffmpeg is terminated.
-        if p.poll() is None:
-
+        if process.poll() is None:
             # Ask ffmpeg to quit
             try:
                 # I read somewhere that modern ffmpeg on Linux prefers a
@@ -360,8 +365,8 @@ def read_frames(
                 # Found that writing to stdin can cause "Invalid argument" on
                 # Windows # and "Broken Pipe" on Unix.
                 # p.stdin.write(b"q")  # commented out in v0.4.1
-                p.stdout.close()
-                p.stdin.close()
+                process.stdout.close()
+                process.stdin.close()
                 # p.stderr.close() -> not here, the log_catcher closes it
             except Exception as err:  # pragma: no cover
                 logger.warning("Error while attempting stop ffmpeg (r): " + str(err))
@@ -370,16 +375,16 @@ def read_frames(
                 # Wait until timeout, produce a warning and kill if it still exists
                 try:
                     etime = time.time() + 1.5
-                    while time.time() < etime and p.poll() is None:
+                    while time.time() < etime and process.poll() is None:
                         time.sleep(0.01)
                 finally:
-                    if p.poll() is None:  # pragma: no cover
+                    if process.poll() is None:  # pragma: no cover
                         logger.warning("We had to kill ffmpeg to stop it.")
-                        p.kill()
+                        process.kill()
 
             else:  # stop_policy == "kill"
                 # Just kill it
-                p.kill()
+                process.kill()
 
 
 def write_frames(
@@ -510,7 +515,16 @@ def write_frames(
         output_params += ["-map", "0:v:0", "-map", "1:a:0"]
 
     # Get command
-    cmd = [_get_exe(), "-y", "-f", "rawvideo", "-vcodec", "rawvideo", "-s", sizestr]
+    cmd = [
+        get_ffmpeg_exe(),
+        "-y",
+        "-f",
+        "rawvideo",
+        "-vcodec",
+        "rawvideo",
+        "-s",
+        sizestr,
+    ]
     cmd += ["-pix_fmt", pix_fmt_in, "-r", "{:.02f}".format(fps)] + input_params
     cmd += ["-i", "-"] + audio_params
     cmd += ["-vcodec", codec, "-pix_fmt", pix_fmt_out]
@@ -595,12 +609,10 @@ def write_frames(
     # Generators are automatically closed when they get deleted,
     # so the finally block is guaranteed to run.
     try:
-
         # Just keep going until the generator.close() is called (raises GeneratorExit).
         # This could also happen when the generator is deleted somehow.
         nframes = 0
         while True:
-
             # Get frame
             bb = yield
 
@@ -639,10 +651,8 @@ def write_frames(
         raise
 
     finally:
-
         # Make sure that ffmpeg is terminated.
         if p.poll() is None:
-
             # Tell ffmpeg that we're done
             try:
                 p.stdin.close()
